About — python-copr 1.63 documentation

# About

Python-copr is a python client to access the Copr build service through its API.

Python-copr right now is in alpha stage, so expect lot of changes. Now it targets python 2.6+ and python3.3+.

- Installation

# Contact

If you have any questions, please contact us:

> - IRC: #fedora-buildsys@irc.freenode.net
> - mailing list: copr-devel@lists.fedorahosted.org [signup] [archives]

# Usage

Copr currently supports three independent API versions.

- Legacy client
- Client version 2
- Client version 3

Both Legacy client and Client version 2 are now obsoleted, please migrate to Client version 3.

# Indices and tables

- Index
- Module Index
- Search Page